Constants class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- androidBuildGradlePath → const String
- androidGoogleServicesPath → const String
- androidManifestPath → const String
- backupDir → const String
- configSection → const String
- iosGoogleServicesPath → const String
- iosInfoPlistExPath → const String
- iosPbxprojPath → const String
- macosGoogleServicesPath → const String
- macosPbxprojPath → const String
- pubspecFile → const String
- webIndexPath → const String
- windowsConfigPath → const String