BackupService class

Constructors

BackupService(Logger logger)

Properties

hashCode int
The hash code for this object.
no setterinherited
logger Logger
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createBackup() Future<String?>
listBackups() List<String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rollback(String timestamp) Future<bool>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited