FirebaseEnvConfig class
Constructors
-
FirebaseEnvConfig({required String name, required String androidConfig, required String iosConfig, required String androidApplicationId, required String iosBundleId, required String appName, String? webConfig, dynamic macosConfig, dynamic macosBundleId, String? windowsConfig, String? windowsApplicationId, Map<
String, String> ? variables, bool runFlutterfire = false, String? flavor, List<Template> ? templates}) - FirebaseEnvConfig.fromYaml(String name, YamlMap map)
-
factory
Properties
- androidApplicationId → String
-
final
- androidConfig → String
-
final
- appName → String
-
final
- flavor → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iosBundleId → String
-
final
- iosConfig → String
-
final
- name → String
-
final
- runFlutterfire → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
templates
→ List<
Template> ? -
final
-
variables
→ Map<
String, String> ? -
final
- webConfig → String?
-
final
- windowsApplicationId → String?
-
final
- windowsConfig → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited