EnvSwitcher class
Constructors
- EnvSwitcher({required Logger logger, required BackupService backupService, required AndroidHandler androidHandler, required IosHandler iosHandler, required Validator validator})
Properties
- androidHandler → AndroidHandler
-
final
- backupService → BackupService
-
final
- env1Name → String
-
no setter
- env2Name → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- iosHandler → IosHandler
-
final
- logger → Logger
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- validator → Validator
-
final
Methods
-
diff(
FirebaseEnvConfig env1, FirebaseEnvConfig env2) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
switchEnv(
FirebaseEnvConfig config) → Future< bool> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited