FirebaseEnvConfig class

Constructors

FirebaseEnvConfig({required String name, required String androidConfig, required String iosConfig, required String androidApplicationId, required String iosBundleId, required String appName})
FirebaseEnvConfig.fromYaml(String name, YamlMap map)
factory

Properties

androidApplicationId String
final
androidConfig String
final
appName String
final
hashCode int
The hash code for this object.
no setterinherited
iosBundleId String
final
iosConfig String
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited